import * as SC from '../styles'
import { useState, useRef, FormEvent } from 'react'
import { useTranslation } from 'react-i18next'
import type { AccountProfileOptions } from '../types'

interface Props {
  options: AccountProfileOptions
  onDelete?: () => void
}

const DeleteAccount: React.FC<Props> = ({
  options: { buttonColor, deleteRequested },
  onDelete
}) => {
  const { t } = useTranslation('accountProfile')

  const [disableButton, setDisableButton] = useState(false)

  const dialogRef = useRef(null)

  const handleShowModal = () => {
    if (dialogRef.current) {
      const element = dialogRef.current as HTMLDialogElement
      element.showModal()
    }
  }

  const handleCloseModal = () => {
    if (dialogRef.current) {
      const element = dialogRef.current as HTMLDialogElement
      element.close()
    }
  }

  const handleDelete = () => {
    setDisableButton(true)
    if (onDelete) onDelete()
  }

  return (
    <>
      <SC.TextDeleteAccount onClick={handleShowModal}>
        {t('deleteTitle')}
      </SC.TextDeleteAccount>
      <SC.DialogConfirmation ref={dialogRef} onClick={handleCloseModal}>
        <SC.DialogContent
          onClick={(e: FormEvent) => {
            e.stopPropagation()
          }}
        >
          <SC.DialogTitle>{t('deleteTitle')}</SC.DialogTitle>
          {deleteRequested ? (
            <SC.DialogResult>{t('deleteSuccess')}</SC.DialogResult>
          ) : (
            <SC.DialogDescription>
              {t('deleteDescription')}
            </SC.DialogDescription>
          )}
          {deleteRequested ? (
            <SC.DialogActionSuccess>
              <SC.DialogActionButton
                style={{
                  width: '78px',
                  color: 'white',
                  backgroundColor: buttonColor,
                  border: `1px solid ${buttonColor}`
                }}
                onClick={handleCloseModal}
              >
                Ok
              </SC.DialogActionButton>
            </SC.DialogActionSuccess>
          ) : (
            <SC.DialogAction>
              <SC.DialogActionButton
                disabled={disableButton}
                style={{
                  color: buttonColor,
                  backgroundColor: 'var(--white)',
                  border: `1px solid ${buttonColor}`
                }}
                onClick={handleCloseModal}
              >
                {t('deleteCancel')}
              </SC.DialogActionButton>
              <SC.DialogActionButton
                disabled={disableButton}
                style={{
                  color: 'white',
                  backgroundColor: buttonColor,
                  border: `1px solid ${buttonColor}`
                }}
                onClick={handleDelete}
              >
                {t('deleteConfirm')}
              </SC.DialogActionButton>
            </SC.DialogAction>
          )}
        </SC.DialogContent>
      </SC.DialogConfirmation>
    </>
  )
}

export default DeleteAccount
