import { useTranslation } from 'react-i18next'
import { Button } from '../styles'
import type { AccountProfileOptions, InvalidField } from '../types'

interface Props {
  edited: boolean
  options: AccountProfileOptions
  initProfile: () => void
  setInvalidFields: React.Dispatch<React.SetStateAction<InvalidField>>
  setEdited: React.Dispatch<React.SetStateAction<boolean>>
}

const DiscardButton: React.FC<Props> = ({
  edited,
  options: { buttonColorSecondary, buttonColor },
  initProfile,
  setInvalidFields,
  setEdited
}) => {
  const { t } = useTranslation('accountProfile')

  const discardChange = () => {
    initProfile()
    setInvalidFields({})
    setEdited(false)
  }

  const disabled = !edited

  return (
    <Button
      disabled={disabled}
      style={{
        color: disabled ? buttonColorSecondary : buttonColor,
        backgroundColor: 'var(--white)',
        border: `1px solid ${buttonColorSecondary}`
      }}
      onClick={discardChange}
    >
      {t('discard')}
    </Button>
  )
}

export default DiscardButton
