import PhoneCodeInput from './PhoneCodeInput'
import ChangeNumber from './ChangeNumber'
import {
  InputIcon,
  InvalidMessage,
  Label,
  TextInput,
  TextInputContainer
} from '../styles'
import type {
  AccountProfileOptions,
  ExtendedProfile,
  InvalidField,
  Profile
} from '../types'
import type { FormEvent } from 'react'

interface Props {
  inputText: {
    id: keyof Profile
    label: string
    icon?: string
  }
  options: AccountProfileOptions
  handleProfileChange: (event: FormEvent) => void
  newProfile: ExtendedProfile
  invalidFields: InvalidField
  onChangeNumber?: () => Promise<void>
}

const PhoneInput: React.FC<Props> = ({
  inputText: { id, label, icon },
  options,
  handleProfileChange,
  invalidFields,
  newProfile,
  onChangeNumber
}) => {
  const { readOnlyPhoneNumber, canEditPhoneNumber } = options

  return (
    <TextInputContainer>
      <Label htmlFor={id}>
        <span style={{ color: 'var(--red)' }}>*</span> {label}
      </Label>
      <TextInput
        name={id}
        style={{
          paddingLeft: '8rem',
          paddingRight: '8rem',
          borderColor: invalidFields[id] ? 'var(--red)' : ''
        }}
        type='text'
        value={newProfile[id]}
        onInput={(e) => handleProfileChange(e)}
        disabled={readOnlyPhoneNumber}
      />
      <PhoneCodeInput
        handleProfileChange={handleProfileChange}
        newProfile={newProfile}
        options={options}
      />
      {icon && <InputIcon src={icon} />}
      {newProfile.phoneNumber && canEditPhoneNumber && (
        <ChangeNumber
          newProfile={newProfile}
          options={options}
          onChangeNumber={onChangeNumber}
        />
      )}
      {invalidFields[id] && (
        <InvalidMessage>Invalid phone number</InvalidMessage>
      )}
    </TextInputContainer>
  )
}

export default PhoneInput
