import { useTranslation } from 'react-i18next'
import {
  DateInput,
  InputIcon,
  InvalidMessage,
  Label,
  TextInput,
  TextInputContainer
} from '../styles'
import type {
  AccountProfileOptions,
  ExtendedProfile,
  InvalidField,
  Profile
} from '../types'
import type { FormEvent } from 'react'

interface Props {
  inputText: {
    id: keyof Profile
    label: string
    icon?: string
    type?: string
  }
  options: AccountProfileOptions
  newProfile: ExtendedProfile
  handleProfileChange: (event: FormEvent) => void
  notRequired?: boolean
  invalidFields: InvalidField
}

const StandardInput: React.FC<Props> = ({
  inputText: { id, label, icon, type = 'text' },
  options: { mode },
  newProfile,
  handleProfileChange,
  notRequired,
  invalidFields
}) => {
  const { t } = useTranslation('accountProfile')

  return type === 'date' ? (
    <DateInput>
      <Label htmlFor={id}>
        {!notRequired && <span style={{ color: 'var(--red)' }}>*</span>} {label}
      </Label>
      <TextInput
        id={id}
        name={id}
        style={{
          paddingLeft: icon ? '2.25rem' : '',
          borderColor: invalidFields[id] ? 'var(--red)' : '',
          colorScheme: mode === 'dark' ? 'dark' : 'light'
        }}
        type={type}
        placeholder='-'
        value={newProfile[id] ? newProfile[id] : ''}
        required={!notRequired}
        pattern={type === 'date' ? '\\d{4}-\\d{2}-\\d{2}' : undefined}
        onInput={handleProfileChange}
      />
      {icon && <InputIcon src={icon} />}
      {invalidFields[id] && (
        <InvalidMessage>
          {label} {t('isRequired')}
        </InvalidMessage>
      )}
    </DateInput>
  ) : (
    <TextInputContainer>
      <Label htmlFor={id}>
        {!notRequired && <span style={{ color: 'var(--red)' }}>*</span>} {label}
      </Label>
      <TextInput
        id={id}
        name={id}
        style={{
          paddingLeft: icon ? '2.25rem' : '',
          borderColor: invalidFields[id] ? 'var(--red)' : ''
        }}
        type={type}
        placeholder='-'
        value={newProfile[id] ? newProfile[id] : ''}
        required={!notRequired}
        pattern={type === 'date' ? '\\d{4}-\\d{2}-\\d{2}' : undefined}
        onInput={handleProfileChange}
      />
      {icon && <InputIcon src={icon} />}
      {invalidFields[id] && (
        <InvalidMessage>
          {label} {t('isRequired')}
        </InvalidMessage>
      )}
    </TextInputContainer>
  )
}

export default StandardInput
