import { useTranslation } from 'react-i18next'
import { validateField } from '../helper'
import { Button } from '../styles'
import type {
  AccountProfileOptions,
  ExtendedProfile,
  InvalidField
} from '../types'

interface Props {
  edited: boolean
  options: AccountProfileOptions
  invalidFields: InvalidField
  setInvalidFields: React.Dispatch<React.SetStateAction<InvalidField>>
  newProfile: ExtendedProfile
  onUpdate: (profile: ExtendedProfile) => void
}

const UpdateButton: React.FC<Props> = ({
  edited,
  options: { buttonColorTertiary, buttonColor },
  invalidFields,
  setInvalidFields,
  newProfile,
  onUpdate
}) => {
  const { t } = useTranslation('accountProfile')

  const getInvalidFields = () => {
    const fields: InvalidField = {}
    Object.keys(newProfile).map((key: string) => {
      const required = document
        .querySelector(`#${key}`)
        ?.hasAttribute('required')

      fields[key] = !validateField(
        key as keyof ExtendedProfile,
        newProfile,
        !required
      )
    })
    return fields
  }

  const onClickUpdate = () => {
    const fields = getInvalidFields()
    setInvalidFields(fields)
    const valid = !Object.keys(fields).find((key) => invalidFields[key])
    if (valid) onUpdate(newProfile)
  }

  const disabled = !edited
  const color = disabled ? buttonColorTertiary : buttonColor

  return (
    <Button
      disabled={disabled}
      style={{
        color: 'white',
        backgroundColor: color,
        border: `1px solid ${color}`
      }}
      onClick={onClickUpdate}
    >
      {t('update')}
    </Button>
  )
}

export default UpdateButton
