import * as SC from '../styles'

import ChangeNumber from './ChangeNumber'
import type { AccountProfileOptions, Profile } from '../types'
import type { UseFormRegisterReturn } from 'react-hook-form'

interface Props {
  inputText: {
    id: keyof Profile
    label: string
    icon?: string
  }
  isEdit: boolean
  options: AccountProfileOptions
  register: UseFormRegisterReturn
  newProfile: Profile
  invalidFields: boolean
  onChangeNumber?: () => Promise<void>
}

const PhoneInput: React.FC<Props> = ({
  inputText: { id, label },
  isEdit,
  options,
  register,
  newProfile,
  onChangeNumber
}) => {
  const { canEditPhoneNumber } = options

  return (
    <SC.FieldContainer>
      <SC.FieldLabel>{label}</SC.FieldLabel>
      {isEdit ? (
        <SC.FieldValue
          style={{
            display: 'flex',
            flexDirection: 'row',
            position: 'relative'
          }}
        >
          <SC.TextInput
            type='text'
            defaultValue={newProfile[id]}
            disabled
            {...register}
          />
          {newProfile.phoneNumber && canEditPhoneNumber && (
            <ChangeNumber
              newProfile={newProfile}
              options={options}
              onChangeNumber={onChangeNumber}
            />
          )}
        </SC.FieldValue>
      ) : (
        <SC.FieldValue>{newProfile.phoneNumber}</SC.FieldValue>
      )}
    </SC.FieldContainer>
  )
}

export default PhoneInput
