import styled from '@emotion/styled'

export const Main = styled.div({
  '--input-border': '1px solid #dfdfdf',
  '--gray': '#eeeeee',
  '--light-black': '#464646',
  '--fair-green': '#56ab2f',
  '--light-green': '#aee581',
  '--pale-green': '#d0ecb4',
  '--transparent-green-1': '#56ab2f26',
  '--transparent-green-2': '#56ab2f33',
  '--white': '#ffffff',
  '--red': '#f34949',
  '--text-title': '#000000',
  '--text-description': '#767780',
  '--dark-black': '#090909',
  '--bold-green': '#258F91',
  '--shine-blue': '#1D84EF',
  '--light-gray': '#dfdfdf',
  '--black-icon': '#033263',
  '--text-persist-white': '#ffffff'
})

export const Container = styled.div({
  display: 'flex',
  justifyContent: 'space-between',
  width: '100%',

  '@media screen and (max-width: 1146.98px)': {
    flexBasis: '100%',
    maxWidth: '100%',
    marginBottom: '16px',
    justifyContent: 'normal',
    flexWrap: 'wrap'
  }
})

export const ProfileContainer = styled.div({
  display: 'flex',
  paddingRight: '48px',
  flex: '1 1 auto',
  justifyContent: 'space-between',

  '@media screen and (max-width: 1146.98px)': {
    flexBasis: '100%',
    maxWidth: '100%',
    marginBottom: '16px',
    paddingRight: '0px'
  }
})

export const ProfileBox = styled.div({
  display: 'flex',
  flexDirection: 'column',
  width: '100%',
  flex: '1 1 auto'
})

export const ChangePasswordContainer = styled.div({
  flex: '0 1 auto',

  '@media screen and (min-width: 1305px)': {
    padding: '0px 48px 0px 24px'
  },

  '@media screen and (max-width: 1146.98px)': {
    flexBasis: '100%',
    maxWidth: '100%',
    marginBottom: '32px',
    padding: '0px'
  }
})

export const ChangePasswordBox = styled.div({
  display: 'flex',
  flexDirection: 'column'
})

export const FieldContainer = styled.div({
  display: 'flex',
  flexBasis: '100%',
  alignItems: 'center',
  marginBottom: '18px',

  '@media screen and (max-width: 576px)': {
    flexBasis: '100%',
    maxWidth: '100%',
    flexDirection: 'column',
    alignItems: 'flex-start'
  }
})

export const FieldLabel = styled.div({
  fontSize: '18px',
  fontWeight: 500,
  lineHeight: '27px',
  color: 'var(--dark-black)',
  display: 'flex',
  flexBasis: '35%',
  maxWidth: '35%',
  flexGrow: 1,

  '@media screen and (max-width: 576px)': {
    flexBasis: '100%',
    maxWidth: '100%'
  },

  '@media screen and (min-width: 1200px)': {
    flexBasis: '30%',
    maxWidth: '30%'
  }
})

export const FieldValue = styled.div({
  fontSize: '18px',
  fontWeight: 400,
  lineHeight: '27px',
  color: 'var(--dark-black)',
  flexBasis: '65%',
  maxWidth: '65%',
  flexGrow: 1,

  '@media screen and (max-width: 576px)': {
    flexBasis: '100%',
    maxWidth: '100%',
    width: '100%'
  },

  '@media screen and (min-width: 1200px)': {
    flexBasis: '70%',
    maxWidth: '70%'
  }
})

export const Paragraph = styled.div({
  flexBasis: '100%',

  fontSize: '18px',
  fontWeight: 500,
  lineHeight: '27px',
  color: 'var(--dark-black)'
})

export const Text = styled.div({
  flexBasis: '50%',
  flexGrow: 1
})

export const SocmedLinkText = styled.div({
  fontSize: '16px',
  fontWeight: 400,
  lineHeight: '24px',
  textAlign: 'left',
  color: 'var(--shine-blue)',
  flexBasis: '65%',
  maxWidth: '65%',
  flexGrow: 1,

  '@media screen and (max-width: 576px)': {
    marginLeft: '44px',
    flexBasis: '100%',
    maxWidth: '100%',
    width: '100%',
    overflowWrap: 'break-word'
  },

  '@media screen and (min-width: 1200px)': {
    flexBasis: '70%',
    maxWidth: '70%'
  }
})

export const TextInput = styled.input({
  flexBasis: '100%',
  width: '100%',
  minWidth: 0,

  fontSize: '18px',
  fontWeight: 400,
  lineHeight: '27px',
  color: 'var(--dark-black)',
  border: 'none',
  borderBottom: 'var(--input-border)',
  backgroundColor: 'transparent',
  transition: 'border-color 0.2s ease-in-out',

  '&:focus': {
    outline: 'none',
    borderColor: 'var(--light-gray)'
  },
  '&:disabled': {
    border: 0,
    borderBottom: 'var(--input-border)',
    borderRadius: 0,
    background: 'transparent'
  }
})

export const SpaceIcon = styled.div({
  marginRight: '16px'
})

export const SocmedIcon = styled.img({
  width: '28px',
  height: '28px'
})

export const ItemIcon = styled.div({
  color: 'var(--black-icon)',
  fontSize: '30px',
  flex: '0 1 auto'
})

export const ButtonContainer = styled.div`
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
  margin-top: 48px;
`

export const Button = styled.button`
  padding: 10px 20px;
  font-size: 16px;
  border: none;
  cursor: pointer;
  font-size: 16px;
  font-weight: 600;
  line-height: 16px;
  letter-spacing: 0.005em;
  border-radius: 8px;
`

export const CancelButton = styled(Button)({
  border: '1px solid var(--bold-green) !important',
  width: '112px',
  height: '42px',
  backgroundColor: 'transparent',
  color: 'var(--bold-green)',

  '&:disabled': {
    background: 'transparent',
    cursor: 'not-allowed',
    opacity: 0.5
  }
})

export const SaveButton = styled(Button)({
  width: '112px',
  height: '42px',
  backgroundColor: 'var(--bold-green)',
  color: 'var(--text-persist-white)',

  '&:disabled': {
    cursor: 'not-allowed',
    opacity: 0.5
  }
})

export const DialogActionSuccess = styled.div({
  marginTop: '25px',
  width: '100%',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center'
})

export const DialogActionButton = styled(Button)({
  width: '130px',
  height: '35px',
  display: 'flex',
  padding: '0px',
  justifyContent: 'center',
  alignItems: 'center',
  fontSize: '0.875rem',
  '&:disabled': {
    opacity: 0.4,
    cursor: 'not-allowed'
  },
  '@media (min-width: 900px)': {
    width: '150px',
    height: '42px',
    fontSize: '1rem'
  }
})

export const ChangeNumberContainer = styled.div({
  position: 'absolute',
  right: '0.75rem',
  display: 'flex',
  alignItems: 'center',
  gap: '5px',
  cursor: 'pointer'
})

export const TextChangeNumber = styled.div({
  fontSize: '0.875rem',
  color: '#2E68FD',
  textDecoration: 'underline'
})

export const TextCountDown = styled.div({
  fontSize: '0.875rem',
  color: 'var(--text-title)'
})

export const DialogConfirmation = styled.dialog({
  width: '327px',
  padding: '0px',
  borderRadius: '10px',
  border: 'none',
  '&::backdrop': {
    background: '#605E5E80'
  },
  '@media (min-width: 900px)': {
    width: '445px'
  }
})

export const DialogContent = styled.div({
  background: 'var(--white)',
  padding: '24px',
  textAlign: 'center',
  '@media (min-width: 900px)': {
    padding: '32px'
  }
})

export const DialogTitle = styled.div({
  color: 'var(--text-title)',
  width: '250px',
  margin: 'auto',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  fontSize: '1rem',
  fontWeight: 700,
  lineHeight: '26px',
  '@media (min-width: 900px)': {
    fontSize: '1.25rem'
  }
})

export const DialogDescription = styled.div({
  width: '256px',
  margin: 'auto',
  marginTop: '6px',
  fontSize: '0.875rem',
  color: 'var(--text-description)',
  lineHeight: '24px',
  whiteSpace: 'pre-line',
  '@media (min-width: 900px)': {
    width: '335px',
    marginTop: '12px',
    fontSize: '1rem'
  }
})

export const DialogResult = styled.div({
  width: '277px',
  margin: 'auto',
  marginTop: '6px',
  fontSize: '0.75rem',
  color: 'var(--text-description)',
  lineHeight: '18px',
  whiteSpace: 'pre-line',
  '@media (min-width: 900px)': {
    width: '368px',
    marginTop: '12px',
    fontSize: '0.875rem',
    lineHeight: '21px'
  }
})

export const DialogAction = styled.div({
  marginTop: '40px',
  width: '100%',
  display: 'flex',
  justifyContent: 'space-between',
  alignItems: 'center'
})
