import * as SC from './FooterStyles'
import List from './List'

import Logo from '../../assets/components/footer/logo-prosa.svg'
import Location from '../../assets/components/footer/location.svg'
import Phone from '../../assets/components/footer/phone.svg'
import Email from '../../assets/components/footer/email.svg'
import Linkedin from '../../assets/components/footer/linkedin.svg'
import Medium from '../../assets/components/footer/medium.svg'
import Instagram from '../../assets/components/footer/instagram.svg'
import Youtube from '../../assets/components/footer/youtube.svg'
import Tiktok from '../../assets/components/footer/tiktok.svg'
import Facebook from '../../assets/components/footer/facebook.svg'
import Twitter from '../../assets/components/footer/twitter.svg'
import ISOLogo from '../../assets/components/footer/iso-logo.png'
import NvidiaLogo from '../../assets/components/footer/nvidia-logo.png'

import { dictionary } from './FooterLocale'

interface BillingualText {
  Indonesia: string
  English: string
}

interface ListItems {
  id: string
  title: BillingualText
  items: {
    id: string
    name: BillingualText
    url: string
    urlEn: string
    isExternalUrl?: boolean
  }[]
}

interface SocialItems {
  id: string
  logo: string
  url: string
}

const currentYear = new Date().getFullYear()

const termsandconditionlink = 'https://prosa.ai/terms-and-conditions'
const privacypolicylink = 'https://prosa.ai/privacy-policy'

const {
  industries,
  company,
  community,
  termsAndCondition,
  privacyPolicy,
  socialTitle
} = dictionary

const footerItems: ListItems[] = [
  {
    id: 'industry',
    title: industries.title,
    items: [
      {
        id: 'industry-bfsi',
        name: industries.bfsi,
        url: '/industry/bfsi',
        urlEn: '/en/industry/bfsi'
      },
      {
        id: 'industry-public_sector',
        name: industries.publicSector,
        url: '/industry/public-sector',
        urlEn: '/en/industry/public-sector'
      },
      {
        id: 'industry-telco',
        name: industries.telco,
        url: '/industry/telco',
        urlEn: '/en/industry/telco'
      },
      {
        id: 'industry-healthcare',
        name: industries.healthcare,
        url: '/industry/healthcare',
        urlEn: '/en/industry/healthcare'
      },
      {
        id: 'industry-edutech',
        name: industries.edutech,
        url: '/industry/edutech',
        urlEn: '/en/industry/edutech'
      },
      {
        id: 'industry-contact_center',
        name: industries.contactCenter,
        url: '/industry/contact-center',
        urlEn: '/en/industry/contact-center'
      }
    ]
  },
  {
    id: 'company',
    title: company.title,
    items: [
      {
        id: 'company-about_us',
        name: company.aboutUs,
        url: '/company',
        urlEn: '/en/company'
      },
      {
        id: 'company-research',
        name: company.research,
        url: '/research',
        urlEn: '/en/research'
      },
      {
        id: 'company-career',
        name: company.careers,
        url: '/career',
        urlEn: '/en/career'
      },
      {
        id: 'company-contact_us',
        name: company.contactUs,
        url: '/contact',
        urlEn: '/en/contact'
      }
    ]
  },
  {
    id: 'community',
    title: community.title,
    items: [
      {
        id: 'community-developers',
        name: community.developers,
        url: 'https://console2.prosa.ai',
        urlEn: 'https://console2.prosa.ai',
        isExternalUrl: true
      },
      {
        id: 'community-partners',
        name: community.partners,
        url: '/partner',
        urlEn: '/en/partner'
      },
      {
        id: 'community-blog',
        name: community.blog,
        url: 'https://blog.prosa.ai',
        urlEn: 'https://blog.prosa.ai',
        isExternalUrl: true
      }
    ]
  }
]

const socialItems: SocialItems[] = [
  {
    id: 'footer-linkedin',
    logo: Linkedin,
    url: 'https://www.linkedin.com/company/prosa-ai/'
  },
  {
    id: 'footer-medium',
    logo: Medium,
    url: 'https://medium.com/prosa-story'
  },
  {
    id: 'footer-instagram',
    logo: Instagram,
    url: 'https://www.instagram.com/prosa.ai/'
  },
  {
    id: 'footer-youtube',
    logo: Youtube,
    url: 'https://www.youtube.com/channel/UCO037Qdyws-2nuiGqa74Hiw'
  },
  {
    id: 'footer-tiktok',
    logo: Tiktok,
    url: 'https://www.tiktok.com/@prosa_ai'
  },
  {
    id: 'footer-facebook',
    logo: Facebook,
    url: 'https://www.facebook.com/prosaai/'
  },
  {
    id: 'footer-twitter',
    logo: Twitter,
    url: 'https://twitter.com/prosa_ai/'
  }
]

export interface FooterProps {
  isonexternal?: boolean
  language?: 'English' | 'Indonesia'
  background?: string
  includecopyright?: boolean
  isbilingualviaurl?: boolean
}

export const Footer: React.FC<FooterProps> = ({
  isonexternal = true,
  language = 'Indonesia',
  background = '#2f4858',
  includecopyright = true,
  isbilingualviaurl = false
}) => {
  const footerLeft = (
    <SC.FooterLeft>
      <img src={Logo} alt='logo-prosa' />
      <SC.FooterMap>
        <SC.ListItem href='https://goo.gl/maps/AXJHACS7haP2' target='_blank'>
          <img src={Location} alt='location-icon' />
          <div>
            PT Prosa Solusi Cerdas
            <br />
            Jalan Dr. Otten No.10
            <br />
            Pasir Kaliki, KeSC. Cicendo
            <br />
            Kota Bandung 40171, Indonesia
          </div>
        </SC.ListItem>
      </SC.FooterMap>
      <SC.FooterPhone>
        <SC.ListItem href='tel:+628-1395468649'>
          <img src={Phone} alt='phone-icon' />
          <div>(+62) 813 9546 8649</div>
        </SC.ListItem>
      </SC.FooterPhone>
      <SC.FooterEmail>
        <SC.ListItem href='mailto:business@prosa.ai'>
          <img src={Email} alt='email-icon' />
          <div>business@prosa.ai</div>
        </SC.ListItem>
      </SC.FooterEmail>
    </SC.FooterLeft>
  )

  const footerRight = (
    <SC.FooterRight>
      <h3>{socialTitle[language]}</h3>
      <SC.SocialContainer>
        {socialItems.map(({ id, logo, url }, index) => (
          <a id={id} href={url} target='_blank' key={id} rel='noreferrer'>
            <img src={logo} alt={'icon-' + index} />
          </a>
        ))}
      </SC.SocialContainer>
    </SC.FooterRight>
  )

  const footerCopyright = (
    <SC.FooterCopyright>
      <p>&copy; {currentYear} PT Prosa Solusi Cerdas. All rights reserved</p>
      <SC.RightContent>
        <a href={termsandconditionlink} target='_blank' rel='noreferrer'>
          {termsAndCondition[language]}
        </a>
        &nbsp;|&nbsp;
        <a href={privacypolicylink} target='_blank' rel='noreferrer'>
          {' '}
          {privacyPolicy[language]}{' '}
        </a>
      </SC.RightContent>
    </SC.FooterCopyright>
  )

  return (
    <SC.Main>
      <SC.FooterRoot style={{ background: background }}>
        <SC.FooterContainer>
          {footerLeft}
          <SC.FooterContainerWrap>
            {footerItems.map(({ id, title, items }) => (
              <List
                key={id}
                title={title[language]}
                items={items.map(({ id, name, url, urlEn, isExternalUrl }) => {
                  let link = url
                  if (isbilingualviaurl && language === 'English') link = urlEn
                  return {
                    key: 'items-' + id,
                    id,
                    name: name[language],
                    url: `${
                      isonexternal && !isExternalUrl ? 'https://prosa.ai' : ''
                    }${link}`,
                    isExternalUrl: isonexternal || isExternalUrl
                  }
                })}
              />
            ))}
            {footerRight}
          </SC.FooterContainerWrap>
          <SC.FooterISO>
            <SC.NvidiaImage src={NvidiaLogo} alt='nvidia' />
            <SC.ISOImage src={ISOLogo} alt='iso' />
          </SC.FooterISO>
        </SC.FooterContainer>
      </SC.FooterRoot>
      {includecopyright && (
        <SC.FooterRoot style={{ width: '100%', background: '#000000' }}>
          <SC.FooterContainer style={{ margin: 0 }}>
            {footerCopyright}
          </SC.FooterContainer>
        </SC.FooterRoot>
      )}
    </SC.Main>
  )
}

export default Footer
