import * as SC from './styles'
import i18next from './../../lib/i18n'
import NewsletterForm from './components/NewsletterForm'
import NewsletterImage from '../../assets/components/newsletter/newsletter.svg'

import { useState, useEffect } from 'react'
import { I18nextProvider, useTranslation, Trans } from 'react-i18next'

import type { NewsletterOptions, NewsletterProps } from './types'

const defaultOptions: NewsletterOptions = {
  background: 'linear-gradient(180deg, #22ff9a 0%, #21cc7e 100%)',
  language: 'id',
  disableSubmit: false
}

export const Newsletter: React.FC<NewsletterProps> = ({
  options,
  onSendEmail
}) => {
  options = { ...defaultOptions, ...options }

  const {
    t,
    i18n: { changeLanguage }
  } = useTranslation('newsletter')

  const { background, language } = options

  useEffect(() => {
    changeLanguage(language)
  }, [changeLanguage, language])

  const [email, setEmail] = useState('')
  const [invalidEmail, setInvalidEmail] = useState(false)
  const [disabledButton, setDisabledButton] = useState(true)

  return (
    <I18nextProvider i18n={i18next}>
      <SC.Main>
        <SC.NewsletterRoot>
          <SC.NewsletterContainer style={{ background: background }}>
            <SC.IllustrationContainer>
              <SC.NewsletterIllustration
                src={NewsletterImage}
                alt='newsletter-illustration'
              />
            </SC.IllustrationContainer>
            <SC.ContentContainer>
              <SC.NewsletterTitle>
                <Trans components={{ italic: <i /> }}>{t('title')}</Trans>
              </SC.NewsletterTitle>
              <SC.NewsletterContent>
                <Trans components={{ italic: <i /> }}>{t('content')}</Trans>
              </SC.NewsletterContent>
            </SC.ContentContainer>
            <SC.FormContainer>
              <NewsletterForm
                options={options}
                email={email}
                setEmail={setEmail}
                invalidEmail={invalidEmail}
                setInvalidEmail={setInvalidEmail}
                disabledButton={disabledButton}
                setDisabledButton={setDisabledButton}
                onSendEmail={onSendEmail}
              />
            </SC.FormContainer>
          </SC.NewsletterContainer>
        </SC.NewsletterRoot>
      </SC.Main>
    </I18nextProvider>
  )
}
