import styled from '@emotion/styled'

export const Main = styled.div({
  display: 'block',
  width: '100%',
  color: '#fff'
})

export const NewsletterRoot = styled.div({
  width: '100%',
  display: 'flex',
  justifyContent: 'center',
  boxSizing: 'initial'
})

export const NewsletterContainer = styled.div({
  width: '100%',
  maxWidth: 'calc(1040px - 10rem)',
  margin: '5rem 6rem',
  padding: '3rem 5rem',
  borderRadius: '10px',
  display: 'flex',
  flexWrap: 'wrap',
  justifyContent: 'flex-end',
  '@media (max-width: 767.98px)': {
    margin: '1rem 2.5rem 2rem',
    padding: '1.5rem'
  }
})

export const IllustrationContainer = styled.div({
  maxWidth: '41.66667%',
  flex: '0 0 41.66667%',
  position: 'relative',
  '@media (max-width: 575.98px)': {
    flex: '0 0 100%',
    maxWidth: '100%'
  }
})

export const ContentContainer = styled.div({
  maxWidth: '58.33333%',
  flex: '0 0 58.33333%',
  '@media (max-width: 575.98px)': {
    flex: '0 0 100%',
    maxWidth: '100%'
  }
})

export const NewsletterIllustration = styled.img({
  width: '75%',
  top: 0,
  position: 'absolute',
  left: '50%',
  transform: 'translateX(-50%)',
  '@media (max-width: 575.98px)': {
    width: '75%',
    top: 0,
    bottom: 'initial',
    position: 'relative'
  },
  '@media (min-width: 576px) and (max-width: 767.98px)': {
    width: '90%',
    top: 'initial',
    bottom: '-1.5rem'
  },
  '@media (min-width: 768px) and (max-width: 1199.98px)': {
    width: '100%'
  }
})

export const NewsletterTitle = styled.h3({
  color: '#116276',
  fontSize: '1.75rem',
  lineHeight: 'normal',
  margin: 0,
  '@media (max-width: 575.98px)': {
    fontSize: '1.4rem'
  }
})

export const NewsletterContent = styled.p({
  color: '#000',
  fontSize: '1.125rem',
  lineHeight: 'normal',
  margin: '1rem 0 0',
  '@media (max-width: 575.98px)': {
    fontSize: '1rem'
  }
})

export const NewsletterForm = styled.div({
  position: 'relative',
  display: 'flex',
  marginTop: '1.75rem',
  '@media (max-width: 991.98px)': {
    display: 'block'
  }
})

export const Input = styled.input({
  width: '100%',
  height: '3.65rem',
  border: 0,
  borderRadius: '5px 0 0 5px',
  fontSize: '1rem',
  padding: '0 1rem',
  flexGrow: 1,
  '&:focus': {
    boxShadow: '0 0 0 0.2rem rgb(220 53 69 / 25%)'
  },
  '@media (max-width: 991.98px)': {
    width: 'calc(100% - 2rem)',
    height: '3.65rem',
    fontSize: '1rem',
    borderRadius: '5px'
  }
})

export const InputInvalid = styled.div({
  color: '#dc3545',
  fontSize: '0.875rem',
  margin: '3.65rem 0 0 1rem',
  position: 'absolute',
  fontWeight: 600,
  '@media (max-width: 991.98px)': {
    margin: '0 0 0 1rem',
    fontSize: '0.875rem'
  }
})

export const SubmitButtonContainer = styled.div({
  flexGrow: 0,
  '@media (max-width: 991.98px)': {
    marginTop: '2rem'
  }
})

export const SubmitButton = styled.button({
  background: '#116276',
  border: 0,
  borderRadius: '0 5px 5px 0',
  fontWeight: 600,
  letterSpacing: '0.1rem',
  fontSize: '1rem',
  color: '#fff',
  height: '3.65rem',
  cursor: 'pointer',
  transition: '0.2s',
  '&:hover:not(:disabled)': {
    color: '#212529'
  },
  '&:disabled': {
    cursor: 'not-allowed',
    color: 'grey'
  },
  '@media (max-width: 991.98px)': {
    width: '100%',
    borderRadius: '5px',
    fontSize: '1rem',
    height: '3.65rem'
  }
})

export const FormContainer = styled.div({
  flex: '0 0 58.33333%',
  maxWidth: '58.333333%',
  '@media (max-width: 991.98px)': {
    flex: '0 0 100%',
    maxWidth: '100%'
  }
})

export const NewsletterRecaptcha = styled.div({
  fontSize: '1rem',
  color: '#000',
  width: '100%',
  marginTop: '1.5rem',
  a: {
    color: '#116276'
  }
})
