import { ContactForm, ContactFormData } from '../components'

export default function ContactFormExample() {
  const handleOnSubmit = async (values: ContactFormData) => {
    const contactFormElement = document.querySelector('.contact-form-component')
    if (values) {
      dispatchIsErrorEvent(contactFormElement, false)
    } else {
      dispatchIsErrorEvent(contactFormElement, true)
    }
  }

  const dispatchIsErrorEvent = (element: Element | null, isError: boolean) => {
    if (element) {
      const event = new CustomEvent('on-submit-contact-form-error', {
        detail: { data: isError }
      })
      element.dispatchEvent(event)
    }
  }

  return (
    <div>
      <ContactForm
        options={{
          applicationName: 'Prosa TTS',
          categoryOptions: [
            {
              value: 'A',
              id: 'Kategori A',
              en: 'Category A'
            },
            {
              value: 'B',
              id: 'Kategori B',
              en: 'Category B'
            },
            {
              value: 'C',
              id: 'Kategori C',
              en: 'Category C'
            },
            {
              value: 'D',
              id: 'Kategori D',
              en: 'Category D'
            },
            {
              value: 'E',
              id: 'Kategori E',
              en: 'Category E'
            }
          ],
          sourceOptions: [
            {
              value: 'Search Engine',
              id: 'Mesin pencarian (Google, Bing, Yandex, dll.)',
              en: 'Search Engine (Google, Bing, Yandex, dll.)'
            },
            {
              value: 'Prosa Web',
              id: 'Web Prosa',
              en: 'Prosa Web'
            },
            {
              value: 'Facebook',
              id: 'Facebook',
              en: 'Facebook'
            },
            {
              value: 'Youtube',
              id: 'Youtube',
              en: 'Youtube'
            },
            {
              value: 'LinkedIn',
              id: 'LinkedIn',
              en: 'LinkedIn'
            },
            {
              value: 'Instagram',
              id: 'Instagram',
              en: 'Instagram'
            },
            {
              value: 'Friend',
              id: 'Teman',
              en: 'Friend'
            },
            {
              value: 'Other',
              id: 'Lainnya',
              en: 'Other'
            }
          ]
        }}
        onSend={(data) => handleOnSubmit(data)}
      >
        <div slot='left-child' style={{ background: 'yellow' }}>
          <h3>
            Slot <code>name=&quot;left-child&quot;</code> to fill the empty
            space.
          </h3>
          <p>
            Lorem ipsum dolor sit amet consectetur adipisicing elit. Suscipit
            nostrum reiciendis libero aspernatur id mollitia nesciunt saepe quia
            ipsum, natus vel obcaecati placeat, consequatur provident.
          </p>
        </div>
      </ContactForm>
    </div>
  )
}
