import { useState } from 'react'
import {
  Parameter,
  TransactionHistory,
  Transactions
} from '../components/transaction-history'

const TRANSACTION_DATA: Transactions[] = [
  {
    orderId: 'APP-0008-0422-00001',
    status: 'new',
    dateTime: '2022-06-01 00:00',
    planType: 'Subscription',
    planName: 'Premium',
    features: [
      'Kuota untuk 3 aplikasi',
      'Masa berlaku 3 tahun',
      'Terkoneksi 400 channel atau lebih',
      'Kuota untuk 3 aplikasi',
      'Terkoneksi dengan 400 channel',
      'Masa berlaku 3 tahun'
    ],
    paymentMethod: 'BCA Mastercard (Debet)',
    totalPrice: 290000,
    paymentLink: 'https://www.google.com/'
  },
  {
    orderId: 'APP-0008-0422-00002',
    status: 'success',
    dateTime: '2022-04-01 10:00',
    planType: 'Subscription',
    planName: 'Bussiness',
    features: [
      'Kuota untuk 3 aplikasi',
      'Masa berlaku 3 tahun',
      'Terkoneksi 400 channel atau lebih',
      'Kuota untuk 3 aplikasi',
      'Terkoneksi dengan 400 channel',
      'Masa berlaku 3 tahun'
    ],
    paymentMethod: 'BCA Mastercard (Debet)',
    totalPrice: 290000,
    paymentLink: 'https://www.google.com/'
  },
  {
    orderId: 'APP-0008-0422-00003',
    status: 'failed',
    dateTime: '2022-04-10 23:05',
    planType: 'Subscription',
    planName: 'Premium',
    features: [
      'Kuota untuk 3 aplikasi',
      'Masa berlaku 3 tahun',
      'Terkoneksi 400 channel atau lebih',
      'Kuota untuk 3 aplikasi',
      'Terkoneksi dengan 400 channel',
      'Masa berlaku 3 tahun'
    ],
    paymentMethod: 'BCA Mastercard (Debet)',
    totalPrice: 290000,
    paymentLink: 'https://www.google.com/'
  },
  {
    orderId: 'APP-0008-0422-00004',
    status: 'pending',
    dateTime: '2022-06-10 07:30',
    planType: 'Single purchase',
    planName: 'Bussiness',
    features: [
      'Kuota untuk 3 aplikasi',
      'Masa berlaku 3 tahun',
      'Terkoneksi 400 channel atau lebih',
      'Kuota untuk 3 aplikasi',
      'Terkoneksi dengan 400 channel',
      'Masa berlaku 3 tahun'
    ],
    paymentMethod: 'BCA Mastercard (Debet)',
    totalPrice: 290000,
    paymentLink: 'https://www.google.com/'
  },
  {
    orderId: 'APP-0008-0422-00005',
    status: 'pending',
    dateTime: '2022-03-01 08:45',
    planType: 'Single purchase',
    planName: 'Premium',
    features: [
      'Kuota untuk 3 aplikasi',
      'Masa berlaku 3 tahun',
      'Terkoneksi 400 channel atau lebih',
      'Kuota untuk 3 aplikasi',
      'Terkoneksi dengan 400 channel',
      'Masa berlaku 3 tahun'
    ],
    paymentMethod: 'BCA Mastercard (Debet)',
    totalPrice: 290000,
    paymentLink: 'https://www.google.com/'
  },
  {
    orderId: 'APP-0008-0422-00006',
    status: 'failed',
    dateTime: '2022-04-20 12:10',
    planType: 'Single purchase',
    planName: 'Bussiness',
    features: [
      'Kuota untuk 3 aplikasi',
      'Masa berlaku 3 tahun',
      'Terkoneksi 400 channel atau lebih',
      'Kuota untuk 3 aplikasi',
      'Terkoneksi dengan 400 channel',
      'Masa berlaku 3 tahun'
    ],
    paymentMethod: 'BCA Mastercard (Debet)',
    totalPrice: 290000,
    paymentLink: 'https://www.google.com/'
  }
]

export default function TransactionHistoryExample() {
  const [stateTransactions, setStateTransactions] = useState([
    ...TRANSACTION_DATA
  ])
  const [total, setTotal] = useState(TRANSACTION_DATA.length)
  const [statePage, setStatePage] = useState(1)
  const [statePageSize, setStatePageSize] = useState('All')
  const [stateSearch, setStateSearch] = useState('')
  const [stateStart, setStateStart] = useState<Date>()
  const [stateEnd, setStateEnd] = useState<Date>()
  const [stateStatus, setStateStatus] = useState('Status')
  const [statePlanType, setStatePlanType] = useState('Plan type')

  const checkStartDate = (input1: string, input2: Date) => {
    const date1 = new Date(input1.split(' ')[0]).getTime()
    const date2 = input2.getTime()
    const diff = date1 - date2
    return diff >= 0
  }

  const checkEndDate = (input1: string, input2: Date) => {
    const date1 = new Date(input1.split(' ')[0]).getTime()
    const date2 = input2.getTime()
    const diff = date1 - date2
    return diff <= 0
  }

  const checkFailed = (items: Transactions[]) => {
    items.forEach(
      (item: { status: string; dateTime: string | number | Date }) => {
        if (item.status === 'Waiting for payment') {
          const date1 = new Date(item.dateTime).getTime()
          const date2 = new Date().getTime()
          const diff = Math.floor((date1 - date2) / 1000) + 3600
          if (diff <= 0) {
            item.status = 'Failed'
          }
        }
      }
    )
  }

  const checkSearch = (item: Transactions, search: string) => {
    if (
      item.orderId.toLowerCase().includes(search.toLowerCase()) ||
      item.planName.toLowerCase().includes(search.toLowerCase())
    ) {
      return true
    } else {
      return false
    }
  }

  const onChangeParameter = (newParameter: Parameter) => {
    try {
      const { page, pageSize, search, start, end, status, planType } =
        newParameter
      let items: Transactions[] = TRANSACTION_DATA
      checkFailed(items)
      if (search) {
        items = items.filter((item: Transactions) => checkSearch(item, search))
      }
      if (start) {
        items = items.filter((item: Transactions) =>
          checkStartDate(item.dateTime, start)
        )
      }
      if (end) {
        items = items.filter((item: Transactions) =>
          checkEndDate(item.dateTime, end)
        )
      }
      if (status !== 'Status') {
        const arrayStatus = [status]
        if (status === 'pending') {
          arrayStatus.push('new')
        }
        items = items.filter((item: Transactions) =>
          arrayStatus.includes(item.status)
        )
      }
      if (planType !== 'Plan type') {
        items = items.filter((item: Transactions) => item.planType === planType)
      }
      if (pageSize !== 'All') {
        items = items.slice(
          (page - 1) * Number(pageSize),
          page * Number(pageSize)
        )
      }
      setStateTransactions(items)
      setTotal(TRANSACTION_DATA.length)
      setStatePage(page)
      setStatePageSize(pageSize)
      setStateSearch(search)
      setStateStart(start)
      setStateEnd(end)
      setStateStatus(status)
      setStatePlanType(planType)
    } catch {
      console.log('error')
    }
  }

  return (
    <div style={{ backgroundColor: 'white', padding: '32px' }}>
      <h1 style={{ marginBottom: '16px' }}>TRANSACTION HISTORY</h1>
      <TransactionHistory
        data={{
          transactions: stateTransactions,
          total: total
        }}
        parameter={{
          page: statePage,
          pageSize: statePageSize,
          search: stateSearch,
          start: stateStart,
          end: stateEnd,
          status: stateStatus,
          planType: statePlanType
        }}
        options={{
          language: 'en',
          mode: 'Light'
        }}
        onChangeParameter={onChangeParameter}
        onDownloadInvoice={() => {}}
      ></TransactionHistory>
    </div>
  )
}
